@@ -13,10 +13,13 @@ from xml.dom.minidom import parse, parseString
 from distutils.version import LooseVersion 
 import csv
 from . import linux
-
 import shutil
+
 NMAP_default = "/usr/bin/nmap"
 NMAP = shutil.which("nmap")
+
+SNMPWALK = shutil.which('snmpwalk')
+
 if NMAP is None:
     NMAP = NMAP_default
 NSE_PATH = os.path.dirname(os.path.realpath(__file__)) + '/nse/'
@@ -34,11 +37,44 @@ NMAP_PRINTERS_PORTS = ['80','161','443','9100','U:161']
 NSE_PRINTERS_PATH  = "/"+os.path.dirname(os.path.realpath(__file__)) + '/nse/printers/'
 NSE_PRINTERS_SCRIPTS = [NSE_PRINTERS_PATH]
 
+NMAP_CCTV_PORTS = ['21','80','161','443','8080','8443','4321', '37777', '9000', '10554', '5985','9100','5060']
+NSE_CCTV_PATH  = "/"+os.path.dirname(os.path.realpath(__file__)) + '/nse/cctv/'
+NSE_CCTV_SCRIPTS = [NSE_CCTV_PATH]
+
 NSE_OTHER_PATH =  "/"+os.path.dirname(os.path.realpath(__file__)) + '/nse/other/' 
 
 def nmap_exists():
     return NMAP and os.access(NMAP, os.X_OK)
 
+def build_snmp_walk_cmd(args, addr):
+    cmd = SNMPWALK
+    if args.snmp_security_name:
+        cmd = cmd + ' -v3 -u '+args.snmp_security_name
+    else:
+        cmd = cmd + ' -v2c '
+    cmd = cmd + ' -c '+args.snmp_community + ' ' + addr
+    return cmd
+
+def get_snmp_oid_value(args, snmpwalk, oid):
+    out = None
+    try:
+        logging.debug("snmpwalk command: " + snmpwalk + ' ' + oid)
+        out = subprocess.check_output([snmpwalk+' '+oid], shell=True)
+        out = out.decode(args.encoding)
+    except subprocess.CalledProcessError:
+        logging.error("Error running snmpwalk command")
+        return out
+    try:
+        if ':' in out:
+            out = out.strip().split(':')[1].replace('"','')
+        else:
+            out = out.strip().split('=')[1].replace('"','')
+    except Exception as e:
+        logging.error("Exception processing snmp oid walk output")
+        return None
+    logging.debug("snmpwalk output: " + out)
+    return out
+
 def discover(args):
     handle = args.handle
     token = args.token
@@ -188,6 +224,12 @@ def create_nmap_cmd (args):
     if "printers" in args.services:
         ports += NMAP_PRINTERS_PORTS
         scripts += NSE_PRINTERS_SCRIPTS
+    if "cctv" in args.services:
+        ports += NMAP_CCTV_PORTS
+        scripts += NSE_CCTV_SCRIPTS
+    if "snmp" in args.services:
+        ports = ['161']
+        vflag = " -sU "
  
     cmd = NMAP + vflag + ' -Pn -oX - -T ' + args.timing + os
     if len(ports) != 0:
@@ -282,6 +324,59 @@ def nmap_scan(args, host):
         services = h.getElementsByTagName("service")
         if services is not None:
             for s in services:
+                if s.getAttribute('name') == 'snmp' and 'snmp' in args.services:
+                    # use snmpwalk to find more
+                    if not SNMPWALK:
+                        logging.warn("snmpwalk command not found")
+                        continue
+                    # build the snmp walk command
+                    cmd = build_snmp_walk_cmd(args, addr)
+                    prod = get_snmp_oid_value(args, cmd, '1.3.6.1.2.1.1.1.0')
+                    if prod:
+                        logging.debug("SNMP sysDescr value:"+prod)
+                        # handle Palo Alto Networks products
+                        if 'Palo Alto Networks' in prod:
+                            #products.append(prod)
+                            # oid for PANOS version
+                            panosver = get_snmp_oid_value(args, cmd, '1.3.6.1.4.1.25461.2.1.2.1.1')
+                            prod = 'paloaltonetworks pan-os '+panosver
+                            products.append(prod)
+                            ostype = 'Palo Alto Networks'
+                        elif 'Juniper Networks' in prod:
+                            version_regex = re.compile(r'\s([0-9A-Za-z_\-]+(\.[0-9A-Za-z_\-]+)+)')
+                            m = re.findall(version_regex, prod)
+                            if m and len(m) > 0:
+                                junosver = 'juniper junos ' + [x[0] for x in m][0]
+                                ostype = 'Juniper'
+                                products.append(junosver)
+                            model = prod.split(',')[1].replace('Inc.','').strip()
+                            if '[' in model and ']' in model:
+                                model = model.split()[1].replace('[','').replace(']','').strip()
+                            else:
+                                model = model.split()[0].strip()
+                            products.append('juniper '+model)
+                        elif 'Honeywell' in prod:
+                            prod = prod.replace(';',' ')
+                            products.append(prod)
+                            os_type = 'Honeywell Printer'
+                        elif 'Zebra' in prod:
+                            prod = prod.split('/')[0].strip()
+                            products.append(prod)
+                            os_type = 'Zebra Printer'
+                        elif 'Fortinet' in prod: # try vendor specific oids
+                            fgosver = get_snmp_oid_value(args, cmd, '1.3.6.1.4.1.12356.101.4.1.1')
+                            if fgosver: # fortios
+                                fgosver = 'fortinet fortios '+fgosver.split(',')[0].replace('v','')
+                                ostype = 'Fortinet'
+                                products.append(fgosver)
+                                fgmodel = get_snmp_oid_value(args, cmd, '1.3.6.1.4.1.12356.100.1.1.1')
+                                if fgmodel:
+                                    model_regex = re.compile(r'\s([A-Za-z]+([0-9]+[A-Za-z]))')
+                                    m = re.findall(model_regex, fgmodel)
+                                    if m and len(m) > 0:
+                                        model = 'fortinet ' + [x[0] for x in m][0]
+                                        products.append(model)
+
                 prod = s.getAttribute('product')
                 if not prod:
                     continue
@@ -291,7 +386,6 @@ def nmap_scan(args, host):
                 prod = prod + ' ' + ver
                 if prod not in products:
                     products.append(prod)
-
         # check for script output
         scripts = h.getElementsByTagName("script")
         for s in scripts:
@@ -426,6 +520,25 @@ def nmap_scan(args, host):
                     if prod not in products:
                         products.append(prod)
                     ostype = 'HP Printer'
+            elif s.getAttribute('id') == 'arecont-cctv':
+                wpout = s.getAttribute('output')
+                if wpout != None:
+                    if wpout not in products:
+                        products.append(wpout)
+                    ostype = 'Arecont Vision'
+            elif s.getAttribute('id') == 'axis-cctv':
+                wpout = s.getAttribute('output')
+                if wpout != None:
+                    if wpout not in products:
+                        products.append(wpout)
+                    ostype = 'Axis Communications'
+            elif s.getAttribute('id') == 'hanwhavision-cctv':
+                wpout = s.getAttribute('output')
+                if wpout != None:
+                    wpout = wpout.replace('Hanwha Vision','hanwhavision').strip()
+                    if wpout not in products:
+                        products.append(wpout)
+                    ostype = 'Hanwha Vision'
 
         os_name_tag = None
         smb_os_name = get_smb_os(h)
@@ -496,14 +609,17 @@ def nmap_scan(args, host):
         asset_tags = ["DISCOVERY_TYPE:Unauthenticated"]
         if os_name_tag:
             asset_tags.append("OS_RELEASE:" + os_name_tag)
+            asset_tags.append(os_name_tag)
         asset_data['tags'] = asset_tags
-        if len(ports_in_use_dict) > 0 and ostype != 'HP Printer':
-            asset_data['config_issues'] = create_open_ports_issues(ports_in_use_dict, addr)
-        if args.no_ssh_audit == False and ssh_port_is_open and ostype != 'HP Printer':
-            ssh_issues = linux.run_ssh_audit(args, addr, addr)
-            if len(ssh_issues) != 0:
-                asset_data['tags'].append('SSH Audit')
-            asset_data['config_issues'] = asset_data['config_issues'] + ssh_issues if 'config_issues' in asset_data else ssh_issues
+
+        if 'printers' not in args.services and 'cctv' not in args.services and 'snmp' not in args.services:
+            if len(ports_in_use_dict) > 0:
+                asset_data['config_issues'] = create_open_ports_issues(ports_in_use_dict, addr)
+            if args.no_ssh_audit == False and ssh_port_is_open:
+                ssh_issues = linux.run_ssh_audit(args, addr, addr)
+                if len(ssh_issues) != 0:
+                    asset_data['tags'].append('SSH Audit')
+                asset_data['config_issues'] = asset_data['config_issues'] + ssh_issues if 'config_issues' in asset_data else ssh_issues
 
         if asset_data['type'] == "Other" and len(asset_data['products']) == 0 and ('config_issues' not in asset_data or len(asset_data['config_issues'])==0):
             # skip any discovered assets which have asset type as "Other" and no products and no config_issues
