@@ -79,9 +79,9 @@ def get_all_devices(args, headers):
                 asset = {}
                 asset['owner'] = args.handle
                 asset['id'] = device['serial']
-                asset['name'] = device['model']
+                asset['name'] = device['name']
                 asset['type'] = 'Cisco'
-                asset_tags = [product_type, net['name'], 'Meraki']
+                asset_tags = ['Cisco Meraki']
                 asset['tags'] = asset_tags
                 model = device['model']
                 if '-' in model:
@@ -102,18 +102,22 @@ def get_all_devices(args, headers):
                 logging.info(jd)
                 asset = {}
                 asset['owner'] = args.handle
-                asset['id'] = device['id']
-                asset['name'] = device['name']
-                if 'osName' in device and 'Android' in device['osName']:
+                asset['id'] = sm_device['id']
+                asset['name'] = sm_device['name']
+                if 'osName' in sm_device and 'Android' in sm_device['osName']:
                     asset['type'] = 'Android'
-                elif 'osName' in device and 'iOS' in device['osName']:
+                elif 'osName' in sm_device and 'iOS' in sm_device['osName']:
                     asset['type'] = 'iPhone'
-                asset_tags = list(set([asset['type'],device['systemModel']])
-                if 'tags' in device:
-                    for t in device['tags']:
+                asset_tags = list(set(['Cisco Meraki MDM', asset['type']]))
+                if 'tags' in sm_device:
+                    for t in sm_device['tags']:
                         asset_tags.append(t)
                 asset['tags'] = asset_tags
-                products = [device['osName']]
+                if 'systemModel' in sm_device and sm_device['systemModel'].startswith('SM-'):
+                    # samsung android - adjust the version number to match dot decimal
+                    products = ['Samsung '+sm_device['osName']+'.0']
+                else:
+                    products = [sm_device['osName']]
                 softwares = get_sm_device_softwares(args, headers, net['id'], sm_device['id'])
                 for software in softwares:
                     js = json.dumps(software, indent=4)
@@ -126,7 +130,7 @@ def get_all_devices(args, headers):
                         vendor = vendor.replace('Corporation','')
                         vendor = vendor.replace('LLC','')
                         vendor = vendor.strip()
-                    prodstr = vendor + ' ' + software['name'] + ' ' + software['version'] 
+                    prodstr = vendor + ' ' + software['name'] + ' ' + software['shortVersion'] 
                     products.append(prodstr)
                 asset['products'] = products
                 assets.append(asset)
